# VideoSDK AWS Plugin

Agent Framework plugin for Realtime and TTS services from AWS.

## Requirements

- Python 3.12+
- AWS Credentials like AWS_SECRET_ACCESS_KEY,AWS_ACCESS_KEY_ID with access to Bedrock,and make sure to enable model `amazon.nova-sonic-v1:0`.

## Installation

```bash
pip install videosdk-plugins-aws
```
